#!/usr/bin/perl

$files=`ls /usr/bin/gnome*`;
print $files;

#wait for input
print('Type return to continue');
$x=<STDIN>;
system('ls','/usr/bin');

print('Type return to continue');
$x=<STDIN>;
system('ls','~');

