#!/bin/bash


for file in $( /bin/ls /usr/bin/gnome* ); do
	echo $file
done

#this is a comment.  wait for the user to type something
echo 'Hit return to continue'
read

cd /usr/bin
ls

echo 'Hit return to continue'
read

cd ~
ls
