#!/bin/tcsh


foreach file  ( /usr/bin/gnome* )
	echo $file
end

#this is a comment.  wait for the user to type something
echo 'Hit return to continue'
$<

cd /usr/bin
ls

echo 'Hit return to continue'
$<

cd ~
ls
