#!/imaging/local/software/anaconda/latest/x86_64/bin/python

import os
import sys
import string

files = os.listdir("/usr/bin")

for i in files :
	if string.find(i,'gnome') > -1 : print i

#Wait for input
print 'Type return to continue'
sys.stdin.read(1)

os.system('ls /usr/lib')

print 'Type return to continue'
sys.stdin.read(1)
os.system('ls ~')

